# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PersistenceProfileSrcAddrArgs', 'PersistenceProfileSrcAddr']

@pulumi.input_type
class PersistenceProfileSrcAddrArgs:
    def __init__(__self__, *,
                 defaults_from: pulumi.Input[_builtins.str],
                 name: pulumi.Input[_builtins.str],
                 app_service: Optional[pulumi.Input[_builtins.str]] = None,
                 hash_algorithm: Optional[pulumi.Input[_builtins.str]] = None,
                 map_proxies: Optional[pulumi.Input[_builtins.str]] = None,
                 mask: Optional[pulumi.Input[_builtins.str]] = None,
                 match_across_pools: Optional[pulumi.Input[_builtins.str]] = None,
                 match_across_services: Optional[pulumi.Input[_builtins.str]] = None,
                 match_across_virtuals: Optional[pulumi.Input[_builtins.str]] = None,
                 mirror: Optional[pulumi.Input[_builtins.str]] = None,
                 override_conn_limit: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a PersistenceProfileSrcAddr resource.
        :param pulumi.Input[_builtins.str] defaults_from: Inherit defaults from parent profile
        :param pulumi.Input[_builtins.str] name: Name of the persistence profile
        :param pulumi.Input[_builtins.str] hash_algorithm: Specify the hash algorithm
        :param pulumi.Input[_builtins.str] map_proxies: To enable _ disable directs all to the same single pool member
        :param pulumi.Input[_builtins.str] mask: Identify a range of source IP addresses to manage together as a single source address affinity persistent connection
               when connecting to the pool. Must be a valid IPv4 or IPv6 mask.
        :param pulumi.Input[_builtins.str] match_across_pools: To enable _ disable match across pools with given persistence record
        :param pulumi.Input[_builtins.str] match_across_services: To enable _ disable match across services with given persistence record
        :param pulumi.Input[_builtins.str] match_across_virtuals: To enable _ disable match across services with given persistence record
        :param pulumi.Input[_builtins.str] mirror: To enable _ disable
        :param pulumi.Input[_builtins.str] override_conn_limit: To enable _ disable that pool member connection limits are overridden for persisted clients. Per-virtual connection
               limits remain hard limits and are not overridden.
        :param pulumi.Input[_builtins.int] timeout: Timeout for persistence of the session
        """
        pulumi.set(__self__, "defaults_from", defaults_from)
        pulumi.set(__self__, "name", name)
        if app_service is not None:
            pulumi.set(__self__, "app_service", app_service)
        if hash_algorithm is not None:
            pulumi.set(__self__, "hash_algorithm", hash_algorithm)
        if map_proxies is not None:
            pulumi.set(__self__, "map_proxies", map_proxies)
        if mask is not None:
            pulumi.set(__self__, "mask", mask)
        if match_across_pools is not None:
            pulumi.set(__self__, "match_across_pools", match_across_pools)
        if match_across_services is not None:
            pulumi.set(__self__, "match_across_services", match_across_services)
        if match_across_virtuals is not None:
            pulumi.set(__self__, "match_across_virtuals", match_across_virtuals)
        if mirror is not None:
            pulumi.set(__self__, "mirror", mirror)
        if override_conn_limit is not None:
            pulumi.set(__self__, "override_conn_limit", override_conn_limit)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> pulumi.Input[_builtins.str]:
        """
        Inherit defaults from parent profile
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "defaults_from", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the persistence profile
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="appService")
    def app_service(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "app_service")

    @app_service.setter
    def app_service(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_service", value)

    @_builtins.property
    @pulumi.getter(name="hashAlgorithm")
    def hash_algorithm(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specify the hash algorithm
        """
        return pulumi.get(self, "hash_algorithm")

    @hash_algorithm.setter
    def hash_algorithm(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hash_algorithm", value)

    @_builtins.property
    @pulumi.getter(name="mapProxies")
    def map_proxies(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        To enable _ disable directs all to the same single pool member
        """
        return pulumi.get(self, "map_proxies")

    @map_proxies.setter
    def map_proxies(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "map_proxies", value)

    @_builtins.property
    @pulumi.getter
    def mask(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identify a range of source IP addresses to manage together as a single source address affinity persistent connection
        when connecting to the pool. Must be a valid IPv4 or IPv6 mask.
        """
        return pulumi.get(self, "mask")

    @mask.setter
    def mask(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mask", value)

    @_builtins.property
    @pulumi.getter(name="matchAcrossPools")
    def match_across_pools(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        To enable _ disable match across pools with given persistence record
        """
        return pulumi.get(self, "match_across_pools")

    @match_across_pools.setter
    def match_across_pools(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "match_across_pools", value)

    @_builtins.property
    @pulumi.getter(name="matchAcrossServices")
    def match_across_services(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        To enable _ disable match across services with given persistence record
        """
        return pulumi.get(self, "match_across_services")

    @match_across_services.setter
    def match_across_services(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "match_across_services", value)

    @_builtins.property
    @pulumi.getter(name="matchAcrossVirtuals")
    def match_across_virtuals(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        To enable _ disable match across services with given persistence record
        """
        return pulumi.get(self, "match_across_virtuals")

    @match_across_virtuals.setter
    def match_across_virtuals(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "match_across_virtuals", value)

    @_builtins.property
    @pulumi.getter
    def mirror(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        To enable _ disable
        """
        return pulumi.get(self, "mirror")

    @mirror.setter
    def mirror(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mirror", value)

    @_builtins.property
    @pulumi.getter(name="overrideConnLimit")
    def override_conn_limit(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        To enable _ disable that pool member connection limits are overridden for persisted clients. Per-virtual connection
        limits remain hard limits and are not overridden.
        """
        return pulumi.get(self, "override_conn_limit")

    @override_conn_limit.setter
    def override_conn_limit(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "override_conn_limit", value)

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timeout for persistence of the session
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "timeout", value)


@pulumi.input_type
class _PersistenceProfileSrcAddrState:
    def __init__(__self__, *,
                 app_service: Optional[pulumi.Input[_builtins.str]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 hash_algorithm: Optional[pulumi.Input[_builtins.str]] = None,
                 map_proxies: Optional[pulumi.Input[_builtins.str]] = None,
                 mask: Optional[pulumi.Input[_builtins.str]] = None,
                 match_across_pools: Optional[pulumi.Input[_builtins.str]] = None,
                 match_across_services: Optional[pulumi.Input[_builtins.str]] = None,
                 match_across_virtuals: Optional[pulumi.Input[_builtins.str]] = None,
                 mirror: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 override_conn_limit: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering PersistenceProfileSrcAddr resources.
        :param pulumi.Input[_builtins.str] defaults_from: Inherit defaults from parent profile
        :param pulumi.Input[_builtins.str] hash_algorithm: Specify the hash algorithm
        :param pulumi.Input[_builtins.str] map_proxies: To enable _ disable directs all to the same single pool member
        :param pulumi.Input[_builtins.str] mask: Identify a range of source IP addresses to manage together as a single source address affinity persistent connection
               when connecting to the pool. Must be a valid IPv4 or IPv6 mask.
        :param pulumi.Input[_builtins.str] match_across_pools: To enable _ disable match across pools with given persistence record
        :param pulumi.Input[_builtins.str] match_across_services: To enable _ disable match across services with given persistence record
        :param pulumi.Input[_builtins.str] match_across_virtuals: To enable _ disable match across services with given persistence record
        :param pulumi.Input[_builtins.str] mirror: To enable _ disable
        :param pulumi.Input[_builtins.str] name: Name of the persistence profile
        :param pulumi.Input[_builtins.str] override_conn_limit: To enable _ disable that pool member connection limits are overridden for persisted clients. Per-virtual connection
               limits remain hard limits and are not overridden.
        :param pulumi.Input[_builtins.int] timeout: Timeout for persistence of the session
        """
        if app_service is not None:
            pulumi.set(__self__, "app_service", app_service)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if hash_algorithm is not None:
            pulumi.set(__self__, "hash_algorithm", hash_algorithm)
        if map_proxies is not None:
            pulumi.set(__self__, "map_proxies", map_proxies)
        if mask is not None:
            pulumi.set(__self__, "mask", mask)
        if match_across_pools is not None:
            pulumi.set(__self__, "match_across_pools", match_across_pools)
        if match_across_services is not None:
            pulumi.set(__self__, "match_across_services", match_across_services)
        if match_across_virtuals is not None:
            pulumi.set(__self__, "match_across_virtuals", match_across_virtuals)
        if mirror is not None:
            pulumi.set(__self__, "mirror", mirror)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if override_conn_limit is not None:
            pulumi.set(__self__, "override_conn_limit", override_conn_limit)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter(name="appService")
    def app_service(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "app_service")

    @app_service.setter
    def app_service(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_service", value)

    @_builtins.property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Inherit defaults from parent profile
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "defaults_from", value)

    @_builtins.property
    @pulumi.getter(name="hashAlgorithm")
    def hash_algorithm(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specify the hash algorithm
        """
        return pulumi.get(self, "hash_algorithm")

    @hash_algorithm.setter
    def hash_algorithm(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hash_algorithm", value)

    @_builtins.property
    @pulumi.getter(name="mapProxies")
    def map_proxies(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        To enable _ disable directs all to the same single pool member
        """
        return pulumi.get(self, "map_proxies")

    @map_proxies.setter
    def map_proxies(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "map_proxies", value)

    @_builtins.property
    @pulumi.getter
    def mask(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identify a range of source IP addresses to manage together as a single source address affinity persistent connection
        when connecting to the pool. Must be a valid IPv4 or IPv6 mask.
        """
        return pulumi.get(self, "mask")

    @mask.setter
    def mask(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mask", value)

    @_builtins.property
    @pulumi.getter(name="matchAcrossPools")
    def match_across_pools(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        To enable _ disable match across pools with given persistence record
        """
        return pulumi.get(self, "match_across_pools")

    @match_across_pools.setter
    def match_across_pools(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "match_across_pools", value)

    @_builtins.property
    @pulumi.getter(name="matchAcrossServices")
    def match_across_services(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        To enable _ disable match across services with given persistence record
        """
        return pulumi.get(self, "match_across_services")

    @match_across_services.setter
    def match_across_services(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "match_across_services", value)

    @_builtins.property
    @pulumi.getter(name="matchAcrossVirtuals")
    def match_across_virtuals(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        To enable _ disable match across services with given persistence record
        """
        return pulumi.get(self, "match_across_virtuals")

    @match_across_virtuals.setter
    def match_across_virtuals(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "match_across_virtuals", value)

    @_builtins.property
    @pulumi.getter
    def mirror(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        To enable _ disable
        """
        return pulumi.get(self, "mirror")

    @mirror.setter
    def mirror(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mirror", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the persistence profile
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="overrideConnLimit")
    def override_conn_limit(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        To enable _ disable that pool member connection limits are overridden for persisted clients. Per-virtual connection
        limits remain hard limits and are not overridden.
        """
        return pulumi.get(self, "override_conn_limit")

    @override_conn_limit.setter
    def override_conn_limit(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "override_conn_limit", value)

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timeout for persistence of the session
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "timeout", value)


@pulumi.type_token("f5bigip:ltm/persistenceProfileSrcAddr:PersistenceProfileSrcAddr")
class PersistenceProfileSrcAddr(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_service: Optional[pulumi.Input[_builtins.str]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 hash_algorithm: Optional[pulumi.Input[_builtins.str]] = None,
                 map_proxies: Optional[pulumi.Input[_builtins.str]] = None,
                 mask: Optional[pulumi.Input[_builtins.str]] = None,
                 match_across_pools: Optional[pulumi.Input[_builtins.str]] = None,
                 match_across_services: Optional[pulumi.Input[_builtins.str]] = None,
                 match_across_virtuals: Optional[pulumi.Input[_builtins.str]] = None,
                 mirror: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 override_conn_limit: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Configures a source address persistence profile

        ## Example

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        srcaddr = f5bigip.ltm.PersistenceProfileSrcAddr("srcaddr",
            name="/Common/terraform_srcaddr",
            defaults_from="/Common/source_addr",
            match_across_pools="enabled",
            match_across_services="enabled",
            match_across_virtuals="enabled",
            mirror="enabled",
            timeout=3600,
            override_conn_limit="enabled",
            hash_algorithm="carp",
            map_proxies="enabled",
            mask="255.255.255.255")
        ```

        ## Reference

        `name` - (Required) Name of the virtual address

        `defaults_from` - (Required) Parent cookie persistence profile

        `match_across_pools` (Optional) (enabled or disabled) match across pools with given persistence record

        `match_across_services` (Optional) (enabled or disabled) match across services with given persistence record

        `match_across_virtuals` (Optional) (enabled or disabled) match across virtual servers with given persistence record

        `mirror` (Optional) (enabled or disabled) mirror persistence record

        `timeout` (Optional) (enabled or disabled) Timeout for persistence of the session in seconds

        `override_conn_limit` (Optional) (enabled or disabled) Enable or dissable pool member connection limits are overridden for persisted clients. Per-virtual connection limits remain hard limits and are not overridden.

        `hash_algorithm` (Optional) Specify the hash algorithm

        `mask` (Optional) Identify a range of source IP addresses to manage together as a single source address affinity persistent connection when connecting to the pool. Must be a valid IPv4 or IPv6 mask.

        `map_proxies` (Optional) (enabled or disabled) Directs all to the same single pool member

        ## Importing

        An source-addr persistence profile can be imported into this resource by supplying the Name in `full path` as `id`.
        An example is below:
        ```sh
        $ terraform import bigip_ltm_persistence_profile_srcaddr.srcaddr "/Common/terraform_srcaddr"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] defaults_from: Inherit defaults from parent profile
        :param pulumi.Input[_builtins.str] hash_algorithm: Specify the hash algorithm
        :param pulumi.Input[_builtins.str] map_proxies: To enable _ disable directs all to the same single pool member
        :param pulumi.Input[_builtins.str] mask: Identify a range of source IP addresses to manage together as a single source address affinity persistent connection
               when connecting to the pool. Must be a valid IPv4 or IPv6 mask.
        :param pulumi.Input[_builtins.str] match_across_pools: To enable _ disable match across pools with given persistence record
        :param pulumi.Input[_builtins.str] match_across_services: To enable _ disable match across services with given persistence record
        :param pulumi.Input[_builtins.str] match_across_virtuals: To enable _ disable match across services with given persistence record
        :param pulumi.Input[_builtins.str] mirror: To enable _ disable
        :param pulumi.Input[_builtins.str] name: Name of the persistence profile
        :param pulumi.Input[_builtins.str] override_conn_limit: To enable _ disable that pool member connection limits are overridden for persisted clients. Per-virtual connection
               limits remain hard limits and are not overridden.
        :param pulumi.Input[_builtins.int] timeout: Timeout for persistence of the session
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PersistenceProfileSrcAddrArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Configures a source address persistence profile

        ## Example

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        srcaddr = f5bigip.ltm.PersistenceProfileSrcAddr("srcaddr",
            name="/Common/terraform_srcaddr",
            defaults_from="/Common/source_addr",
            match_across_pools="enabled",
            match_across_services="enabled",
            match_across_virtuals="enabled",
            mirror="enabled",
            timeout=3600,
            override_conn_limit="enabled",
            hash_algorithm="carp",
            map_proxies="enabled",
            mask="255.255.255.255")
        ```

        ## Reference

        `name` - (Required) Name of the virtual address

        `defaults_from` - (Required) Parent cookie persistence profile

        `match_across_pools` (Optional) (enabled or disabled) match across pools with given persistence record

        `match_across_services` (Optional) (enabled or disabled) match across services with given persistence record

        `match_across_virtuals` (Optional) (enabled or disabled) match across virtual servers with given persistence record

        `mirror` (Optional) (enabled or disabled) mirror persistence record

        `timeout` (Optional) (enabled or disabled) Timeout for persistence of the session in seconds

        `override_conn_limit` (Optional) (enabled or disabled) Enable or dissable pool member connection limits are overridden for persisted clients. Per-virtual connection limits remain hard limits and are not overridden.

        `hash_algorithm` (Optional) Specify the hash algorithm

        `mask` (Optional) Identify a range of source IP addresses to manage together as a single source address affinity persistent connection when connecting to the pool. Must be a valid IPv4 or IPv6 mask.

        `map_proxies` (Optional) (enabled or disabled) Directs all to the same single pool member

        ## Importing

        An source-addr persistence profile can be imported into this resource by supplying the Name in `full path` as `id`.
        An example is below:
        ```sh
        $ terraform import bigip_ltm_persistence_profile_srcaddr.srcaddr "/Common/terraform_srcaddr"
        ```

        :param str resource_name: The name of the resource.
        :param PersistenceProfileSrcAddrArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PersistenceProfileSrcAddrArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_service: Optional[pulumi.Input[_builtins.str]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 hash_algorithm: Optional[pulumi.Input[_builtins.str]] = None,
                 map_proxies: Optional[pulumi.Input[_builtins.str]] = None,
                 mask: Optional[pulumi.Input[_builtins.str]] = None,
                 match_across_pools: Optional[pulumi.Input[_builtins.str]] = None,
                 match_across_services: Optional[pulumi.Input[_builtins.str]] = None,
                 match_across_virtuals: Optional[pulumi.Input[_builtins.str]] = None,
                 mirror: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 override_conn_limit: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PersistenceProfileSrcAddrArgs.__new__(PersistenceProfileSrcAddrArgs)

            __props__.__dict__["app_service"] = app_service
            if defaults_from is None and not opts.urn:
                raise TypeError("Missing required property 'defaults_from'")
            __props__.__dict__["defaults_from"] = defaults_from
            __props__.__dict__["hash_algorithm"] = hash_algorithm
            __props__.__dict__["map_proxies"] = map_proxies
            __props__.__dict__["mask"] = mask
            __props__.__dict__["match_across_pools"] = match_across_pools
            __props__.__dict__["match_across_services"] = match_across_services
            __props__.__dict__["match_across_virtuals"] = match_across_virtuals
            __props__.__dict__["mirror"] = mirror
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["override_conn_limit"] = override_conn_limit
            __props__.__dict__["timeout"] = timeout
        super(PersistenceProfileSrcAddr, __self__).__init__(
            'f5bigip:ltm/persistenceProfileSrcAddr:PersistenceProfileSrcAddr',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_service: Optional[pulumi.Input[_builtins.str]] = None,
            defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
            hash_algorithm: Optional[pulumi.Input[_builtins.str]] = None,
            map_proxies: Optional[pulumi.Input[_builtins.str]] = None,
            mask: Optional[pulumi.Input[_builtins.str]] = None,
            match_across_pools: Optional[pulumi.Input[_builtins.str]] = None,
            match_across_services: Optional[pulumi.Input[_builtins.str]] = None,
            match_across_virtuals: Optional[pulumi.Input[_builtins.str]] = None,
            mirror: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            override_conn_limit: Optional[pulumi.Input[_builtins.str]] = None,
            timeout: Optional[pulumi.Input[_builtins.int]] = None) -> 'PersistenceProfileSrcAddr':
        """
        Get an existing PersistenceProfileSrcAddr resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] defaults_from: Inherit defaults from parent profile
        :param pulumi.Input[_builtins.str] hash_algorithm: Specify the hash algorithm
        :param pulumi.Input[_builtins.str] map_proxies: To enable _ disable directs all to the same single pool member
        :param pulumi.Input[_builtins.str] mask: Identify a range of source IP addresses to manage together as a single source address affinity persistent connection
               when connecting to the pool. Must be a valid IPv4 or IPv6 mask.
        :param pulumi.Input[_builtins.str] match_across_pools: To enable _ disable match across pools with given persistence record
        :param pulumi.Input[_builtins.str] match_across_services: To enable _ disable match across services with given persistence record
        :param pulumi.Input[_builtins.str] match_across_virtuals: To enable _ disable match across services with given persistence record
        :param pulumi.Input[_builtins.str] mirror: To enable _ disable
        :param pulumi.Input[_builtins.str] name: Name of the persistence profile
        :param pulumi.Input[_builtins.str] override_conn_limit: To enable _ disable that pool member connection limits are overridden for persisted clients. Per-virtual connection
               limits remain hard limits and are not overridden.
        :param pulumi.Input[_builtins.int] timeout: Timeout for persistence of the session
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PersistenceProfileSrcAddrState.__new__(_PersistenceProfileSrcAddrState)

        __props__.__dict__["app_service"] = app_service
        __props__.__dict__["defaults_from"] = defaults_from
        __props__.__dict__["hash_algorithm"] = hash_algorithm
        __props__.__dict__["map_proxies"] = map_proxies
        __props__.__dict__["mask"] = mask
        __props__.__dict__["match_across_pools"] = match_across_pools
        __props__.__dict__["match_across_services"] = match_across_services
        __props__.__dict__["match_across_virtuals"] = match_across_virtuals
        __props__.__dict__["mirror"] = mirror
        __props__.__dict__["name"] = name
        __props__.__dict__["override_conn_limit"] = override_conn_limit
        __props__.__dict__["timeout"] = timeout
        return PersistenceProfileSrcAddr(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appService")
    def app_service(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "app_service")

    @_builtins.property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> pulumi.Output[_builtins.str]:
        """
        Inherit defaults from parent profile
        """
        return pulumi.get(self, "defaults_from")

    @_builtins.property
    @pulumi.getter(name="hashAlgorithm")
    def hash_algorithm(self) -> pulumi.Output[_builtins.str]:
        """
        Specify the hash algorithm
        """
        return pulumi.get(self, "hash_algorithm")

    @_builtins.property
    @pulumi.getter(name="mapProxies")
    def map_proxies(self) -> pulumi.Output[_builtins.str]:
        """
        To enable _ disable directs all to the same single pool member
        """
        return pulumi.get(self, "map_proxies")

    @_builtins.property
    @pulumi.getter
    def mask(self) -> pulumi.Output[_builtins.str]:
        """
        Identify a range of source IP addresses to manage together as a single source address affinity persistent connection
        when connecting to the pool. Must be a valid IPv4 or IPv6 mask.
        """
        return pulumi.get(self, "mask")

    @_builtins.property
    @pulumi.getter(name="matchAcrossPools")
    def match_across_pools(self) -> pulumi.Output[_builtins.str]:
        """
        To enable _ disable match across pools with given persistence record
        """
        return pulumi.get(self, "match_across_pools")

    @_builtins.property
    @pulumi.getter(name="matchAcrossServices")
    def match_across_services(self) -> pulumi.Output[_builtins.str]:
        """
        To enable _ disable match across services with given persistence record
        """
        return pulumi.get(self, "match_across_services")

    @_builtins.property
    @pulumi.getter(name="matchAcrossVirtuals")
    def match_across_virtuals(self) -> pulumi.Output[_builtins.str]:
        """
        To enable _ disable match across services with given persistence record
        """
        return pulumi.get(self, "match_across_virtuals")

    @_builtins.property
    @pulumi.getter
    def mirror(self) -> pulumi.Output[_builtins.str]:
        """
        To enable _ disable
        """
        return pulumi.get(self, "mirror")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the persistence profile
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="overrideConnLimit")
    def override_conn_limit(self) -> pulumi.Output[_builtins.str]:
        """
        To enable _ disable that pool member connection limits are overridden for persisted clients. Per-virtual connection
        limits remain hard limits and are not overridden.
        """
        return pulumi.get(self, "override_conn_limit")

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> pulumi.Output[_builtins.int]:
        """
        Timeout for persistence of the session
        """
        return pulumi.get(self, "timeout")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RouteArgs', 'Route']

@pulumi.input_type
class RouteArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[_builtins.str],
                 network: pulumi.Input[_builtins.str],
                 gw: Optional[pulumi.Input[_builtins.str]] = None,
                 reject: Optional[pulumi.Input[_builtins.bool]] = None,
                 tunnel_ref: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Route resource.
        :param pulumi.Input[_builtins.str] name: Name of the route.Name of Route should be full path,full path is the combination of the `partition + route name`,For ex: `/Common/test-net-route`.
        :param pulumi.Input[_builtins.str] network: The destination subnet and netmask for the route.
        :param pulumi.Input[_builtins.str] gw: Specifies a gateway address for the route.
        :param pulumi.Input[_builtins.bool] reject: reject route
        :param pulumi.Input[_builtins.str] tunnel_ref: tunnel_ref to route traffic
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "network", network)
        if gw is not None:
            pulumi.set(__self__, "gw", gw)
        if reject is not None:
            pulumi.set(__self__, "reject", reject)
        if tunnel_ref is not None:
            pulumi.set(__self__, "tunnel_ref", tunnel_ref)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the route.Name of Route should be full path,full path is the combination of the `partition + route name`,For ex: `/Common/test-net-route`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def network(self) -> pulumi.Input[_builtins.str]:
        """
        The destination subnet and netmask for the route.
        """
        return pulumi.get(self, "network")

    @network.setter
    def network(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "network", value)

    @_builtins.property
    @pulumi.getter
    def gw(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a gateway address for the route.
        """
        return pulumi.get(self, "gw")

    @gw.setter
    def gw(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "gw", value)

    @_builtins.property
    @pulumi.getter
    def reject(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        reject route
        """
        return pulumi.get(self, "reject")

    @reject.setter
    def reject(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "reject", value)

    @_builtins.property
    @pulumi.getter(name="tunnelRef")
    def tunnel_ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        tunnel_ref to route traffic
        """
        return pulumi.get(self, "tunnel_ref")

    @tunnel_ref.setter
    def tunnel_ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tunnel_ref", value)


@pulumi.input_type
class _RouteState:
    def __init__(__self__, *,
                 gw: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network: Optional[pulumi.Input[_builtins.str]] = None,
                 reject: Optional[pulumi.Input[_builtins.bool]] = None,
                 tunnel_ref: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Route resources.
        :param pulumi.Input[_builtins.str] gw: Specifies a gateway address for the route.
        :param pulumi.Input[_builtins.str] name: Name of the route.Name of Route should be full path,full path is the combination of the `partition + route name`,For ex: `/Common/test-net-route`.
        :param pulumi.Input[_builtins.str] network: The destination subnet and netmask for the route.
        :param pulumi.Input[_builtins.bool] reject: reject route
        :param pulumi.Input[_builtins.str] tunnel_ref: tunnel_ref to route traffic
        """
        if gw is not None:
            pulumi.set(__self__, "gw", gw)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network is not None:
            pulumi.set(__self__, "network", network)
        if reject is not None:
            pulumi.set(__self__, "reject", reject)
        if tunnel_ref is not None:
            pulumi.set(__self__, "tunnel_ref", tunnel_ref)

    @_builtins.property
    @pulumi.getter
    def gw(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a gateway address for the route.
        """
        return pulumi.get(self, "gw")

    @gw.setter
    def gw(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "gw", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the route.Name of Route should be full path,full path is the combination of the `partition + route name`,For ex: `/Common/test-net-route`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def network(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The destination subnet and netmask for the route.
        """
        return pulumi.get(self, "network")

    @network.setter
    def network(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "network", value)

    @_builtins.property
    @pulumi.getter
    def reject(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        reject route
        """
        return pulumi.get(self, "reject")

    @reject.setter
    def reject(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "reject", value)

    @_builtins.property
    @pulumi.getter(name="tunnelRef")
    def tunnel_ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        tunnel_ref to route traffic
        """
        return pulumi.get(self, "tunnel_ref")

    @tunnel_ref.setter
    def tunnel_ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tunnel_ref", value)


@pulumi.type_token("f5bigip:net/route:Route")
class Route(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 gw: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network: Optional[pulumi.Input[_builtins.str]] = None,
                 reject: Optional[pulumi.Input[_builtins.bool]] = None,
                 tunnel_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        `net.Route` Manages a route configuration

        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        route2 = f5bigip.net.Route("route2",
            name="/Common/external-route",
            network="10.10.10.0/24",
            gw="1.1.1.2")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] gw: Specifies a gateway address for the route.
        :param pulumi.Input[_builtins.str] name: Name of the route.Name of Route should be full path,full path is the combination of the `partition + route name`,For ex: `/Common/test-net-route`.
        :param pulumi.Input[_builtins.str] network: The destination subnet and netmask for the route.
        :param pulumi.Input[_builtins.bool] reject: reject route
        :param pulumi.Input[_builtins.str] tunnel_ref: tunnel_ref to route traffic
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RouteArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `net.Route` Manages a route configuration

        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        route2 = f5bigip.net.Route("route2",
            name="/Common/external-route",
            network="10.10.10.0/24",
            gw="1.1.1.2")
        ```

        :param str resource_name: The name of the resource.
        :param RouteArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RouteArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 gw: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network: Optional[pulumi.Input[_builtins.str]] = None,
                 reject: Optional[pulumi.Input[_builtins.bool]] = None,
                 tunnel_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RouteArgs.__new__(RouteArgs)

            __props__.__dict__["gw"] = gw
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            if network is None and not opts.urn:
                raise TypeError("Missing required property 'network'")
            __props__.__dict__["network"] = network
            __props__.__dict__["reject"] = reject
            __props__.__dict__["tunnel_ref"] = tunnel_ref
        super(Route, __self__).__init__(
            'f5bigip:net/route:Route',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            gw: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            network: Optional[pulumi.Input[_builtins.str]] = None,
            reject: Optional[pulumi.Input[_builtins.bool]] = None,
            tunnel_ref: Optional[pulumi.Input[_builtins.str]] = None) -> 'Route':
        """
        Get an existing Route resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] gw: Specifies a gateway address for the route.
        :param pulumi.Input[_builtins.str] name: Name of the route.Name of Route should be full path,full path is the combination of the `partition + route name`,For ex: `/Common/test-net-route`.
        :param pulumi.Input[_builtins.str] network: The destination subnet and netmask for the route.
        :param pulumi.Input[_builtins.bool] reject: reject route
        :param pulumi.Input[_builtins.str] tunnel_ref: tunnel_ref to route traffic
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RouteState.__new__(_RouteState)

        __props__.__dict__["gw"] = gw
        __props__.__dict__["name"] = name
        __props__.__dict__["network"] = network
        __props__.__dict__["reject"] = reject
        __props__.__dict__["tunnel_ref"] = tunnel_ref
        return Route(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def gw(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies a gateway address for the route.
        """
        return pulumi.get(self, "gw")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the route.Name of Route should be full path,full path is the combination of the `partition + route name`,For ex: `/Common/test-net-route`.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def network(self) -> pulumi.Output[_builtins.str]:
        """
        The destination subnet and netmask for the route.
        """
        return pulumi.get(self, "network")

    @_builtins.property
    @pulumi.getter
    def reject(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        reject route
        """
        return pulumi.get(self, "reject")

    @_builtins.property
    @pulumi.getter(name="tunnelRef")
    def tunnel_ref(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        tunnel_ref to route traffic
        """
        return pulumi.get(self, "tunnel_ref")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetPolicyResult',
    'AwaitableGetPolicyResult',
    'get_policy',
    'get_policy_output',
]

@pulumi.output_type
class GetPolicyResult:
    """
    A collection of values returned by getPolicy.
    """
    def __init__(__self__, controls=None, id=None, name=None, published_copy=None, requires=None, rules=None, strategy=None):
        if controls and not isinstance(controls, list):
            raise TypeError("Expected argument 'controls' to be a list")
        pulumi.set(__self__, "controls", controls)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if published_copy and not isinstance(published_copy, str):
            raise TypeError("Expected argument 'published_copy' to be a str")
        pulumi.set(__self__, "published_copy", published_copy)
        if requires and not isinstance(requires, list):
            raise TypeError("Expected argument 'requires' to be a list")
        pulumi.set(__self__, "requires", requires)
        if rules and not isinstance(rules, list):
            raise TypeError("Expected argument 'rules' to be a list")
        pulumi.set(__self__, "rules", rules)
        if strategy and not isinstance(strategy, str):
            raise TypeError("Expected argument 'strategy' to be a str")
        pulumi.set(__self__, "strategy", strategy)

    @_builtins.property
    @pulumi.getter
    def controls(self) -> Optional[Sequence[_builtins.str]]:
        """
        Specifies the controls.
        """
        return pulumi.get(self, "controls")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the policy.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="publishedCopy")
    def published_copy(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "published_copy")

    @_builtins.property
    @pulumi.getter
    def requires(self) -> Optional[Sequence[_builtins.str]]:
        """
        Specifies the protocol.
        """
        return pulumi.get(self, "requires")

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[Sequence['outputs.GetPolicyRuleResult']]:
        """
        Rules defined in the policy.
        """
        return pulumi.get(self, "rules")

    @_builtins.property
    @pulumi.getter
    def strategy(self) -> Optional[_builtins.str]:
        """
        Specifies the match strategy.
        """
        return pulumi.get(self, "strategy")


class AwaitableGetPolicyResult(GetPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPolicyResult(
            controls=self.controls,
            id=self.id,
            name=self.name,
            published_copy=self.published_copy,
            requires=self.requires,
            rules=self.rules,
            strategy=self.strategy)


def get_policy(controls: Optional[Sequence[_builtins.str]] = None,
               name: Optional[_builtins.str] = None,
               published_copy: Optional[_builtins.str] = None,
               requires: Optional[Sequence[_builtins.str]] = None,
               rules: Optional[Sequence[Union['GetPolicyRuleArgs', 'GetPolicyRuleArgsDict']]] = None,
               strategy: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPolicyResult:
    """
    Use this data source (`ltm.Policy`) to get the ltm policy details available on BIG-IP

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    test = f5bigip.ltm.get_policy(name="/Common/test-policy")
    pulumi.export("bigipPolicy", test.rules)
    ```


    :param Sequence[_builtins.str] controls: Specifies the controls.
    :param _builtins.str name: Name of the policy which includes partion ( /partition/policy-name )
    :param Sequence[_builtins.str] requires: Specifies the protocol.
    :param Sequence[Union['GetPolicyRuleArgs', 'GetPolicyRuleArgsDict']] rules: Rules defined in the policy.
    :param _builtins.str strategy: Specifies the match strategy.
    """
    __args__ = dict()
    __args__['controls'] = controls
    __args__['name'] = name
    __args__['publishedCopy'] = published_copy
    __args__['requires'] = requires
    __args__['rules'] = rules
    __args__['strategy'] = strategy
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:ltm/getPolicy:getPolicy', __args__, opts=opts, typ=GetPolicyResult).value

    return AwaitableGetPolicyResult(
        controls=pulumi.get(__ret__, 'controls'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        published_copy=pulumi.get(__ret__, 'published_copy'),
        requires=pulumi.get(__ret__, 'requires'),
        rules=pulumi.get(__ret__, 'rules'),
        strategy=pulumi.get(__ret__, 'strategy'))
def get_policy_output(controls: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                      name: Optional[pulumi.Input[_builtins.str]] = None,
                      published_copy: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      requires: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                      rules: Optional[pulumi.Input[Optional[Sequence[Union['GetPolicyRuleArgs', 'GetPolicyRuleArgsDict']]]]] = None,
                      strategy: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPolicyResult]:
    """
    Use this data source (`ltm.Policy`) to get the ltm policy details available on BIG-IP

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    test = f5bigip.ltm.get_policy(name="/Common/test-policy")
    pulumi.export("bigipPolicy", test.rules)
    ```


    :param Sequence[_builtins.str] controls: Specifies the controls.
    :param _builtins.str name: Name of the policy which includes partion ( /partition/policy-name )
    :param Sequence[_builtins.str] requires: Specifies the protocol.
    :param Sequence[Union['GetPolicyRuleArgs', 'GetPolicyRuleArgsDict']] rules: Rules defined in the policy.
    :param _builtins.str strategy: Specifies the match strategy.
    """
    __args__ = dict()
    __args__['controls'] = controls
    __args__['name'] = name
    __args__['publishedCopy'] = published_copy
    __args__['requires'] = requires
    __args__['rules'] = rules
    __args__['strategy'] = strategy
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('f5bigip:ltm/getPolicy:getPolicy', __args__, opts=opts, typ=GetPolicyResult)
    return __ret__.apply(lambda __response__: GetPolicyResult(
        controls=pulumi.get(__response__, 'controls'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        published_copy=pulumi.get(__response__, 'published_copy'),
        requires=pulumi.get(__response__, 'requires'),
        rules=pulumi.get(__response__, 'rules'),
        strategy=pulumi.get(__response__, 'strategy')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SaasBotDefenseProfileArgs', 'SaasBotDefenseProfile']

@pulumi.input_type
class SaasBotDefenseProfileArgs:
    def __init__(__self__, *,
                 api_key: pulumi.Input[_builtins.str],
                 application_id: pulumi.Input[_builtins.str],
                 name: pulumi.Input[_builtins.str],
                 protected_endpoints: pulumi.Input[Sequence[pulumi.Input['SaasBotDefenseProfileProtectedEndpointArgs']]],
                 shape_protection_pool: pulumi.Input[_builtins.str],
                 ssl_profile: pulumi.Input[_builtins.str],
                 tenant_id: pulumi.Input[_builtins.str],
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SaasBotDefenseProfile resource.
        :param pulumi.Input[_builtins.str] api_key: Specifies the API key, enter the value provided by F5 Support.
        :param pulumi.Input[_builtins.str] application_id: Specifies the Bot Defense API application ID, enter the value provided by F5 Support
        :param pulumi.Input[_builtins.str] name: Unique name for the Distributed Cloud Services Bot Defense profile
        :param pulumi.Input[Sequence[pulumi.Input['SaasBotDefenseProfileProtectedEndpointArgs']]] protected_endpoints: Use these settings to configure which pages on the website will be protected by BD
        :param pulumi.Input[_builtins.str] shape_protection_pool: Specifies the web hostname to which API requests are made
        :param pulumi.Input[_builtins.str] ssl_profile: Specifies a server-side SSL profile that is different from what the application pool uses
        :param pulumi.Input[_builtins.str] tenant_id: Specifies the tenant ID, enter the value provided by F5 Support
        :param pulumi.Input[_builtins.str] defaults_from: Distributed Cloud Services Bot Defense parent profile from which this profile will inherit settings.
        :param pulumi.Input[_builtins.str] description: Specifies descriptive text that identifies the BD profile.
        """
        pulumi.set(__self__, "api_key", api_key)
        pulumi.set(__self__, "application_id", application_id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "protected_endpoints", protected_endpoints)
        pulumi.set(__self__, "shape_protection_pool", shape_protection_pool)
        pulumi.set(__self__, "ssl_profile", ssl_profile)
        pulumi.set(__self__, "tenant_id", tenant_id)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the API key, enter the value provided by F5 Support.
        """
        return pulumi.get(self, "api_key")

    @api_key.setter
    def api_key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "api_key", value)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the Bot Defense API application ID, enter the value provided by F5 Support
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "application_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        Unique name for the Distributed Cloud Services Bot Defense profile
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="protectedEndpoints")
    def protected_endpoints(self) -> pulumi.Input[Sequence[pulumi.Input['SaasBotDefenseProfileProtectedEndpointArgs']]]:
        """
        Use these settings to configure which pages on the website will be protected by BD
        """
        return pulumi.get(self, "protected_endpoints")

    @protected_endpoints.setter
    def protected_endpoints(self, value: pulumi.Input[Sequence[pulumi.Input['SaasBotDefenseProfileProtectedEndpointArgs']]]):
        pulumi.set(self, "protected_endpoints", value)

    @_builtins.property
    @pulumi.getter(name="shapeProtectionPool")
    def shape_protection_pool(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the web hostname to which API requests are made
        """
        return pulumi.get(self, "shape_protection_pool")

    @shape_protection_pool.setter
    def shape_protection_pool(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "shape_protection_pool", value)

    @_builtins.property
    @pulumi.getter(name="sslProfile")
    def ssl_profile(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies a server-side SSL profile that is different from what the application pool uses
        """
        return pulumi.get(self, "ssl_profile")

    @ssl_profile.setter
    def ssl_profile(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "ssl_profile", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the tenant ID, enter the value provided by F5 Support
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "tenant_id", value)

    @_builtins.property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Distributed Cloud Services Bot Defense parent profile from which this profile will inherit settings.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "defaults_from", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies descriptive text that identifies the BD profile.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _SaasBotDefenseProfileState:
    def __init__(__self__, *,
                 api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 protected_endpoints: Optional[pulumi.Input[Sequence[pulumi.Input['SaasBotDefenseProfileProtectedEndpointArgs']]]] = None,
                 shape_protection_pool: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SaasBotDefenseProfile resources.
        :param pulumi.Input[_builtins.str] api_key: Specifies the API key, enter the value provided by F5 Support.
        :param pulumi.Input[_builtins.str] application_id: Specifies the Bot Defense API application ID, enter the value provided by F5 Support
        :param pulumi.Input[_builtins.str] defaults_from: Distributed Cloud Services Bot Defense parent profile from which this profile will inherit settings.
        :param pulumi.Input[_builtins.str] description: Specifies descriptive text that identifies the BD profile.
        :param pulumi.Input[_builtins.str] name: Unique name for the Distributed Cloud Services Bot Defense profile
        :param pulumi.Input[Sequence[pulumi.Input['SaasBotDefenseProfileProtectedEndpointArgs']]] protected_endpoints: Use these settings to configure which pages on the website will be protected by BD
        :param pulumi.Input[_builtins.str] shape_protection_pool: Specifies the web hostname to which API requests are made
        :param pulumi.Input[_builtins.str] ssl_profile: Specifies a server-side SSL profile that is different from what the application pool uses
        :param pulumi.Input[_builtins.str] tenant_id: Specifies the tenant ID, enter the value provided by F5 Support
        """
        if api_key is not None:
            pulumi.set(__self__, "api_key", api_key)
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protected_endpoints is not None:
            pulumi.set(__self__, "protected_endpoints", protected_endpoints)
        if shape_protection_pool is not None:
            pulumi.set(__self__, "shape_protection_pool", shape_protection_pool)
        if ssl_profile is not None:
            pulumi.set(__self__, "ssl_profile", ssl_profile)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the API key, enter the value provided by F5 Support.
        """
        return pulumi.get(self, "api_key")

    @api_key.setter
    def api_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_key", value)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the Bot Defense API application ID, enter the value provided by F5 Support
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "application_id", value)

    @_builtins.property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Distributed Cloud Services Bot Defense parent profile from which this profile will inherit settings.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "defaults_from", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies descriptive text that identifies the BD profile.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique name for the Distributed Cloud Services Bot Defense profile
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="protectedEndpoints")
    def protected_endpoints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SaasBotDefenseProfileProtectedEndpointArgs']]]]:
        """
        Use these settings to configure which pages on the website will be protected by BD
        """
        return pulumi.get(self, "protected_endpoints")

    @protected_endpoints.setter
    def protected_endpoints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SaasBotDefenseProfileProtectedEndpointArgs']]]]):
        pulumi.set(self, "protected_endpoints", value)

    @_builtins.property
    @pulumi.getter(name="shapeProtectionPool")
    def shape_protection_pool(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the web hostname to which API requests are made
        """
        return pulumi.get(self, "shape_protection_pool")

    @shape_protection_pool.setter
    def shape_protection_pool(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "shape_protection_pool", value)

    @_builtins.property
    @pulumi.getter(name="sslProfile")
    def ssl_profile(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a server-side SSL profile that is different from what the application pool uses
        """
        return pulumi.get(self, "ssl_profile")

    @ssl_profile.setter
    def ssl_profile(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ssl_profile", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the tenant ID, enter the value provided by F5 Support
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.type_token("f5bigip:index/saasBotDefenseProfile:SaasBotDefenseProfile")
class SaasBotDefenseProfile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 protected_endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SaasBotDefenseProfileProtectedEndpointArgs', 'SaasBotDefenseProfileProtectedEndpointArgsDict']]]]] = None,
                 shape_protection_pool: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create a SaasBotDefenseProfile resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_key: Specifies the API key, enter the value provided by F5 Support.
        :param pulumi.Input[_builtins.str] application_id: Specifies the Bot Defense API application ID, enter the value provided by F5 Support
        :param pulumi.Input[_builtins.str] defaults_from: Distributed Cloud Services Bot Defense parent profile from which this profile will inherit settings.
        :param pulumi.Input[_builtins.str] description: Specifies descriptive text that identifies the BD profile.
        :param pulumi.Input[_builtins.str] name: Unique name for the Distributed Cloud Services Bot Defense profile
        :param pulumi.Input[Sequence[pulumi.Input[Union['SaasBotDefenseProfileProtectedEndpointArgs', 'SaasBotDefenseProfileProtectedEndpointArgsDict']]]] protected_endpoints: Use these settings to configure which pages on the website will be protected by BD
        :param pulumi.Input[_builtins.str] shape_protection_pool: Specifies the web hostname to which API requests are made
        :param pulumi.Input[_builtins.str] ssl_profile: Specifies a server-side SSL profile that is different from what the application pool uses
        :param pulumi.Input[_builtins.str] tenant_id: Specifies the tenant ID, enter the value provided by F5 Support
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SaasBotDefenseProfileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a SaasBotDefenseProfile resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param SaasBotDefenseProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SaasBotDefenseProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 protected_endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SaasBotDefenseProfileProtectedEndpointArgs', 'SaasBotDefenseProfileProtectedEndpointArgsDict']]]]] = None,
                 shape_protection_pool: Optional[pulumi.Input[_builtins.str]] = None,
                 ssl_profile: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SaasBotDefenseProfileArgs.__new__(SaasBotDefenseProfileArgs)

            if api_key is None and not opts.urn:
                raise TypeError("Missing required property 'api_key'")
            __props__.__dict__["api_key"] = None if api_key is None else pulumi.Output.secret(api_key)
            if application_id is None and not opts.urn:
                raise TypeError("Missing required property 'application_id'")
            __props__.__dict__["application_id"] = None if application_id is None else pulumi.Output.secret(application_id)
            __props__.__dict__["defaults_from"] = defaults_from
            __props__.__dict__["description"] = description
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            if protected_endpoints is None and not opts.urn:
                raise TypeError("Missing required property 'protected_endpoints'")
            __props__.__dict__["protected_endpoints"] = protected_endpoints
            if shape_protection_pool is None and not opts.urn:
                raise TypeError("Missing required property 'shape_protection_pool'")
            __props__.__dict__["shape_protection_pool"] = shape_protection_pool
            if ssl_profile is None and not opts.urn:
                raise TypeError("Missing required property 'ssl_profile'")
            __props__.__dict__["ssl_profile"] = ssl_profile
            if tenant_id is None and not opts.urn:
                raise TypeError("Missing required property 'tenant_id'")
            __props__.__dict__["tenant_id"] = tenant_id
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["apiKey", "applicationId"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SaasBotDefenseProfile, __self__).__init__(
            'f5bigip:index/saasBotDefenseProfile:SaasBotDefenseProfile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_key: Optional[pulumi.Input[_builtins.str]] = None,
            application_id: Optional[pulumi.Input[_builtins.str]] = None,
            defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            protected_endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SaasBotDefenseProfileProtectedEndpointArgs', 'SaasBotDefenseProfileProtectedEndpointArgsDict']]]]] = None,
            shape_protection_pool: Optional[pulumi.Input[_builtins.str]] = None,
            ssl_profile: Optional[pulumi.Input[_builtins.str]] = None,
            tenant_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'SaasBotDefenseProfile':
        """
        Get an existing SaasBotDefenseProfile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_key: Specifies the API key, enter the value provided by F5 Support.
        :param pulumi.Input[_builtins.str] application_id: Specifies the Bot Defense API application ID, enter the value provided by F5 Support
        :param pulumi.Input[_builtins.str] defaults_from: Distributed Cloud Services Bot Defense parent profile from which this profile will inherit settings.
        :param pulumi.Input[_builtins.str] description: Specifies descriptive text that identifies the BD profile.
        :param pulumi.Input[_builtins.str] name: Unique name for the Distributed Cloud Services Bot Defense profile
        :param pulumi.Input[Sequence[pulumi.Input[Union['SaasBotDefenseProfileProtectedEndpointArgs', 'SaasBotDefenseProfileProtectedEndpointArgsDict']]]] protected_endpoints: Use these settings to configure which pages on the website will be protected by BD
        :param pulumi.Input[_builtins.str] shape_protection_pool: Specifies the web hostname to which API requests are made
        :param pulumi.Input[_builtins.str] ssl_profile: Specifies a server-side SSL profile that is different from what the application pool uses
        :param pulumi.Input[_builtins.str] tenant_id: Specifies the tenant ID, enter the value provided by F5 Support
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SaasBotDefenseProfileState.__new__(_SaasBotDefenseProfileState)

        __props__.__dict__["api_key"] = api_key
        __props__.__dict__["application_id"] = application_id
        __props__.__dict__["defaults_from"] = defaults_from
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["protected_endpoints"] = protected_endpoints
        __props__.__dict__["shape_protection_pool"] = shape_protection_pool
        __props__.__dict__["ssl_profile"] = ssl_profile
        __props__.__dict__["tenant_id"] = tenant_id
        return SaasBotDefenseProfile(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the API key, enter the value provided by F5 Support.
        """
        return pulumi.get(self, "api_key")

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the Bot Defense API application ID, enter the value provided by F5 Support
        """
        return pulumi.get(self, "application_id")

    @_builtins.property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Distributed Cloud Services Bot Defense parent profile from which this profile will inherit settings.
        """
        return pulumi.get(self, "defaults_from")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies descriptive text that identifies the BD profile.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Unique name for the Distributed Cloud Services Bot Defense profile
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="protectedEndpoints")
    def protected_endpoints(self) -> pulumi.Output[Sequence['outputs.SaasBotDefenseProfileProtectedEndpoint']]:
        """
        Use these settings to configure which pages on the website will be protected by BD
        """
        return pulumi.get(self, "protected_endpoints")

    @_builtins.property
    @pulumi.getter(name="shapeProtectionPool")
    def shape_protection_pool(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the web hostname to which API requests are made
        """
        return pulumi.get(self, "shape_protection_pool")

    @_builtins.property
    @pulumi.getter(name="sslProfile")
    def ssl_profile(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies a server-side SSL profile that is different from what the application pool uses
        """
        return pulumi.get(self, "ssl_profile")

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the tenant ID, enter the value provided by F5 Support
        """
        return pulumi.get(self, "tenant_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProfileRewriteArgs', 'ProfileRewrite']

@pulumi.input_type
class ProfileRewriteArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[_builtins.str],
                 rewrite_mode: pulumi.Input[_builtins.str],
                 bypass_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ca_file: Optional[pulumi.Input[_builtins.str]] = None,
                 cache_type: Optional[pulumi.Input[_builtins.str]] = None,
                 cookie_rules: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteCookieRuleArgs']]]] = None,
                 crl_file: Optional[pulumi.Input[_builtins.str]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 requests: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteRequestArgs']]]] = None,
                 responses: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteResponseArgs']]]] = None,
                 rewrite_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 signing_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 signing_key: Optional[pulumi.Input[_builtins.str]] = None,
                 signing_key_password: Optional[pulumi.Input[_builtins.str]] = None,
                 split_tunneling: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ProfileRewrite resource.
        :param pulumi.Input[_builtins.str] name: Name of the rewrite profile. ( profile name should be in full path which is combination of partition and profile name )
        :param pulumi.Input[_builtins.str] rewrite_mode: Specifies the type of Client caching. Valid choices are: `portal, uri-translation`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] bypass_lists: Specifies a list of URIs to bypass inside a web page when the page is accessed using Portal Access.
        :param pulumi.Input[_builtins.str] ca_file: Specifies a CA against which to verify signed Java applets signatures. (name should be in full path which is combination of partition and CA file name )
        :param pulumi.Input[_builtins.str] cache_type: Specifies the type of Client caching. Valid choices are: `cache-css-js, cache-all, no-cache, cache-img-css-js`. Default value: `cache-img-css-js`
        :param pulumi.Input[Sequence[pulumi.Input['ProfileRewriteCookieRuleArgs']]] cookie_rules: Specifies the cookie rewrite rules. Block type. Each request is block type with following arguments.
        :param pulumi.Input[_builtins.str] crl_file: Specifies a CRL against which to verify signed Java applets signature certificates. The default option is `none`.
        :param pulumi.Input[_builtins.str] defaults_from: Specifies the profile from which this profile inherits settings. The default is the system-supplied `rewrite` profile.
        :param pulumi.Input[Sequence[pulumi.Input['ProfileRewriteRequestArgs']]] requests: Block type. Each request is block type with following arguments.
        :param pulumi.Input[Sequence[pulumi.Input['ProfileRewriteResponseArgs']]] responses: Block type. Each request is block type with following arguments.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] rewrite_lists: Specifies a list of URIs to rewrite inside a web page when the page is accessed using Portal Access.
        :param pulumi.Input[_builtins.str] signing_cert: Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and certificate name )
        :param pulumi.Input[_builtins.str] signing_key: Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and key name )
        :param pulumi.Input[_builtins.str] signing_key_password: Specifies a pass phrase to use for encrypting the private signing key. Since it's a sensitive entity idempotency will fail in the update call.
        :param pulumi.Input[_builtins.str] split_tunneling: Specifies the type of Client caching. Valid choices are: `true, false`
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "rewrite_mode", rewrite_mode)
        if bypass_lists is not None:
            pulumi.set(__self__, "bypass_lists", bypass_lists)
        if ca_file is not None:
            pulumi.set(__self__, "ca_file", ca_file)
        if cache_type is not None:
            pulumi.set(__self__, "cache_type", cache_type)
        if cookie_rules is not None:
            pulumi.set(__self__, "cookie_rules", cookie_rules)
        if crl_file is not None:
            pulumi.set(__self__, "crl_file", crl_file)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if requests is not None:
            pulumi.set(__self__, "requests", requests)
        if responses is not None:
            pulumi.set(__self__, "responses", responses)
        if rewrite_lists is not None:
            pulumi.set(__self__, "rewrite_lists", rewrite_lists)
        if signing_cert is not None:
            pulumi.set(__self__, "signing_cert", signing_cert)
        if signing_key is not None:
            pulumi.set(__self__, "signing_key", signing_key)
        if signing_key_password is not None:
            pulumi.set(__self__, "signing_key_password", signing_key_password)
        if split_tunneling is not None:
            pulumi.set(__self__, "split_tunneling", split_tunneling)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the rewrite profile. ( profile name should be in full path which is combination of partition and profile name )
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="rewriteMode")
    def rewrite_mode(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the type of Client caching. Valid choices are: `portal, uri-translation`
        """
        return pulumi.get(self, "rewrite_mode")

    @rewrite_mode.setter
    def rewrite_mode(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "rewrite_mode", value)

    @_builtins.property
    @pulumi.getter(name="bypassLists")
    def bypass_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies a list of URIs to bypass inside a web page when the page is accessed using Portal Access.
        """
        return pulumi.get(self, "bypass_lists")

    @bypass_lists.setter
    def bypass_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "bypass_lists", value)

    @_builtins.property
    @pulumi.getter(name="caFile")
    def ca_file(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a CA against which to verify signed Java applets signatures. (name should be in full path which is combination of partition and CA file name )
        """
        return pulumi.get(self, "ca_file")

    @ca_file.setter
    def ca_file(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ca_file", value)

    @_builtins.property
    @pulumi.getter(name="cacheType")
    def cache_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the type of Client caching. Valid choices are: `cache-css-js, cache-all, no-cache, cache-img-css-js`. Default value: `cache-img-css-js`
        """
        return pulumi.get(self, "cache_type")

    @cache_type.setter
    def cache_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cache_type", value)

    @_builtins.property
    @pulumi.getter(name="cookieRules")
    def cookie_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteCookieRuleArgs']]]]:
        """
        Specifies the cookie rewrite rules. Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "cookie_rules")

    @cookie_rules.setter
    def cookie_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteCookieRuleArgs']]]]):
        pulumi.set(self, "cookie_rules", value)

    @_builtins.property
    @pulumi.getter(name="crlFile")
    def crl_file(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a CRL against which to verify signed Java applets signature certificates. The default option is `none`.
        """
        return pulumi.get(self, "crl_file")

    @crl_file.setter
    def crl_file(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "crl_file", value)

    @_builtins.property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the profile from which this profile inherits settings. The default is the system-supplied `rewrite` profile.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "defaults_from", value)

    @_builtins.property
    @pulumi.getter
    def requests(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteRequestArgs']]]]:
        """
        Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "requests")

    @requests.setter
    def requests(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteRequestArgs']]]]):
        pulumi.set(self, "requests", value)

    @_builtins.property
    @pulumi.getter
    def responses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteResponseArgs']]]]:
        """
        Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "responses")

    @responses.setter
    def responses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteResponseArgs']]]]):
        pulumi.set(self, "responses", value)

    @_builtins.property
    @pulumi.getter(name="rewriteLists")
    def rewrite_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies a list of URIs to rewrite inside a web page when the page is accessed using Portal Access.
        """
        return pulumi.get(self, "rewrite_lists")

    @rewrite_lists.setter
    def rewrite_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "rewrite_lists", value)

    @_builtins.property
    @pulumi.getter(name="signingCert")
    def signing_cert(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and certificate name )
        """
        return pulumi.get(self, "signing_cert")

    @signing_cert.setter
    def signing_cert(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "signing_cert", value)

    @_builtins.property
    @pulumi.getter(name="signingKey")
    def signing_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and key name )
        """
        return pulumi.get(self, "signing_key")

    @signing_key.setter
    def signing_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "signing_key", value)

    @_builtins.property
    @pulumi.getter(name="signingKeyPassword")
    def signing_key_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a pass phrase to use for encrypting the private signing key. Since it's a sensitive entity idempotency will fail in the update call.
        """
        return pulumi.get(self, "signing_key_password")

    @signing_key_password.setter
    def signing_key_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "signing_key_password", value)

    @_builtins.property
    @pulumi.getter(name="splitTunneling")
    def split_tunneling(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the type of Client caching. Valid choices are: `true, false`
        """
        return pulumi.get(self, "split_tunneling")

    @split_tunneling.setter
    def split_tunneling(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "split_tunneling", value)


@pulumi.input_type
class _ProfileRewriteState:
    def __init__(__self__, *,
                 bypass_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ca_file: Optional[pulumi.Input[_builtins.str]] = None,
                 cache_type: Optional[pulumi.Input[_builtins.str]] = None,
                 cookie_rules: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteCookieRuleArgs']]]] = None,
                 crl_file: Optional[pulumi.Input[_builtins.str]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 requests: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteRequestArgs']]]] = None,
                 responses: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteResponseArgs']]]] = None,
                 rewrite_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 rewrite_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 signing_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 signing_key: Optional[pulumi.Input[_builtins.str]] = None,
                 signing_key_password: Optional[pulumi.Input[_builtins.str]] = None,
                 split_tunneling: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProfileRewrite resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] bypass_lists: Specifies a list of URIs to bypass inside a web page when the page is accessed using Portal Access.
        :param pulumi.Input[_builtins.str] ca_file: Specifies a CA against which to verify signed Java applets signatures. (name should be in full path which is combination of partition and CA file name )
        :param pulumi.Input[_builtins.str] cache_type: Specifies the type of Client caching. Valid choices are: `cache-css-js, cache-all, no-cache, cache-img-css-js`. Default value: `cache-img-css-js`
        :param pulumi.Input[Sequence[pulumi.Input['ProfileRewriteCookieRuleArgs']]] cookie_rules: Specifies the cookie rewrite rules. Block type. Each request is block type with following arguments.
        :param pulumi.Input[_builtins.str] crl_file: Specifies a CRL against which to verify signed Java applets signature certificates. The default option is `none`.
        :param pulumi.Input[_builtins.str] defaults_from: Specifies the profile from which this profile inherits settings. The default is the system-supplied `rewrite` profile.
        :param pulumi.Input[_builtins.str] name: Name of the rewrite profile. ( profile name should be in full path which is combination of partition and profile name )
        :param pulumi.Input[Sequence[pulumi.Input['ProfileRewriteRequestArgs']]] requests: Block type. Each request is block type with following arguments.
        :param pulumi.Input[Sequence[pulumi.Input['ProfileRewriteResponseArgs']]] responses: Block type. Each request is block type with following arguments.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] rewrite_lists: Specifies a list of URIs to rewrite inside a web page when the page is accessed using Portal Access.
        :param pulumi.Input[_builtins.str] rewrite_mode: Specifies the type of Client caching. Valid choices are: `portal, uri-translation`
        :param pulumi.Input[_builtins.str] signing_cert: Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and certificate name )
        :param pulumi.Input[_builtins.str] signing_key: Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and key name )
        :param pulumi.Input[_builtins.str] signing_key_password: Specifies a pass phrase to use for encrypting the private signing key. Since it's a sensitive entity idempotency will fail in the update call.
        :param pulumi.Input[_builtins.str] split_tunneling: Specifies the type of Client caching. Valid choices are: `true, false`
        """
        if bypass_lists is not None:
            pulumi.set(__self__, "bypass_lists", bypass_lists)
        if ca_file is not None:
            pulumi.set(__self__, "ca_file", ca_file)
        if cache_type is not None:
            pulumi.set(__self__, "cache_type", cache_type)
        if cookie_rules is not None:
            pulumi.set(__self__, "cookie_rules", cookie_rules)
        if crl_file is not None:
            pulumi.set(__self__, "crl_file", crl_file)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if requests is not None:
            pulumi.set(__self__, "requests", requests)
        if responses is not None:
            pulumi.set(__self__, "responses", responses)
        if rewrite_lists is not None:
            pulumi.set(__self__, "rewrite_lists", rewrite_lists)
        if rewrite_mode is not None:
            pulumi.set(__self__, "rewrite_mode", rewrite_mode)
        if signing_cert is not None:
            pulumi.set(__self__, "signing_cert", signing_cert)
        if signing_key is not None:
            pulumi.set(__self__, "signing_key", signing_key)
        if signing_key_password is not None:
            pulumi.set(__self__, "signing_key_password", signing_key_password)
        if split_tunneling is not None:
            pulumi.set(__self__, "split_tunneling", split_tunneling)

    @_builtins.property
    @pulumi.getter(name="bypassLists")
    def bypass_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies a list of URIs to bypass inside a web page when the page is accessed using Portal Access.
        """
        return pulumi.get(self, "bypass_lists")

    @bypass_lists.setter
    def bypass_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "bypass_lists", value)

    @_builtins.property
    @pulumi.getter(name="caFile")
    def ca_file(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a CA against which to verify signed Java applets signatures. (name should be in full path which is combination of partition and CA file name )
        """
        return pulumi.get(self, "ca_file")

    @ca_file.setter
    def ca_file(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ca_file", value)

    @_builtins.property
    @pulumi.getter(name="cacheType")
    def cache_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the type of Client caching. Valid choices are: `cache-css-js, cache-all, no-cache, cache-img-css-js`. Default value: `cache-img-css-js`
        """
        return pulumi.get(self, "cache_type")

    @cache_type.setter
    def cache_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cache_type", value)

    @_builtins.property
    @pulumi.getter(name="cookieRules")
    def cookie_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteCookieRuleArgs']]]]:
        """
        Specifies the cookie rewrite rules. Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "cookie_rules")

    @cookie_rules.setter
    def cookie_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteCookieRuleArgs']]]]):
        pulumi.set(self, "cookie_rules", value)

    @_builtins.property
    @pulumi.getter(name="crlFile")
    def crl_file(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a CRL against which to verify signed Java applets signature certificates. The default option is `none`.
        """
        return pulumi.get(self, "crl_file")

    @crl_file.setter
    def crl_file(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "crl_file", value)

    @_builtins.property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the profile from which this profile inherits settings. The default is the system-supplied `rewrite` profile.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "defaults_from", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the rewrite profile. ( profile name should be in full path which is combination of partition and profile name )
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def requests(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteRequestArgs']]]]:
        """
        Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "requests")

    @requests.setter
    def requests(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteRequestArgs']]]]):
        pulumi.set(self, "requests", value)

    @_builtins.property
    @pulumi.getter
    def responses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteResponseArgs']]]]:
        """
        Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "responses")

    @responses.setter
    def responses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProfileRewriteResponseArgs']]]]):
        pulumi.set(self, "responses", value)

    @_builtins.property
    @pulumi.getter(name="rewriteLists")
    def rewrite_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies a list of URIs to rewrite inside a web page when the page is accessed using Portal Access.
        """
        return pulumi.get(self, "rewrite_lists")

    @rewrite_lists.setter
    def rewrite_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "rewrite_lists", value)

    @_builtins.property
    @pulumi.getter(name="rewriteMode")
    def rewrite_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the type of Client caching. Valid choices are: `portal, uri-translation`
        """
        return pulumi.get(self, "rewrite_mode")

    @rewrite_mode.setter
    def rewrite_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rewrite_mode", value)

    @_builtins.property
    @pulumi.getter(name="signingCert")
    def signing_cert(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and certificate name )
        """
        return pulumi.get(self, "signing_cert")

    @signing_cert.setter
    def signing_cert(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "signing_cert", value)

    @_builtins.property
    @pulumi.getter(name="signingKey")
    def signing_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and key name )
        """
        return pulumi.get(self, "signing_key")

    @signing_key.setter
    def signing_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "signing_key", value)

    @_builtins.property
    @pulumi.getter(name="signingKeyPassword")
    def signing_key_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies a pass phrase to use for encrypting the private signing key. Since it's a sensitive entity idempotency will fail in the update call.
        """
        return pulumi.get(self, "signing_key_password")

    @signing_key_password.setter
    def signing_key_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "signing_key_password", value)

    @_builtins.property
    @pulumi.getter(name="splitTunneling")
    def split_tunneling(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the type of Client caching. Valid choices are: `true, false`
        """
        return pulumi.get(self, "split_tunneling")

    @split_tunneling.setter
    def split_tunneling(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "split_tunneling", value)


@pulumi.type_token("f5bigip:ltm/profileRewrite:ProfileRewrite")
class ProfileRewrite(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bypass_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ca_file: Optional[pulumi.Input[_builtins.str]] = None,
                 cache_type: Optional[pulumi.Input[_builtins.str]] = None,
                 cookie_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteCookieRuleArgs', 'ProfileRewriteCookieRuleArgsDict']]]]] = None,
                 crl_file: Optional[pulumi.Input[_builtins.str]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 requests: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteRequestArgs', 'ProfileRewriteRequestArgsDict']]]]] = None,
                 responses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteResponseArgs', 'ProfileRewriteResponseArgsDict']]]]] = None,
                 rewrite_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 rewrite_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 signing_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 signing_key: Optional[pulumi.Input[_builtins.str]] = None,
                 signing_key_password: Optional[pulumi.Input[_builtins.str]] = None,
                 split_tunneling: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        `bigip_ltm_rewrite_profile` Configures ltm policies to manage traffic assigned to a virtual server

        For resources should be named with their `full path`. The full path is the combination of the `partition + name` of the resource. For example `/Common/test-profile`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        test_profile = f5bigip.ltm.ProfileRewrite("test-profile",
            name="/Common/tf_profile",
            defaults_from="/Common/rewrite",
            bypass_lists=["http://notouch.com"],
            rewrite_lists=["http://some.com"],
            rewrite_mode="portal",
            cache_type="cache-img-css-js",
            ca_file="/Common/ca-bundle.crt",
            crl_file="none",
            signing_cert="/Common/default.crt",
            signing_key="/Common/default.key",
            split_tunneling="true")
        test_profile2 = f5bigip.ltm.ProfileRewrite("test-profile2",
            name="/Common/tf_profile_translate",
            defaults_from="/Common/rewrite",
            rewrite_mode="uri-translation",
            requests=[{
                "insert_xfwd_for": "enabled",
                "insert_xfwd_host": "disabled",
                "insert_xfwd_protocol": "enabled",
                "rewrite_headers": "disabled",
            }],
            responses=[{
                "rewrite_content": "enabled",
                "rewrite_headers": "disabled",
            }],
            cookie_rules=[
                {
                    "rule_name": "cookie1",
                    "client_domain": "wrong.com",
                    "client_path": "/this/",
                    "server_domain": "wrong.com",
                    "server_path": "/this/",
                },
                {
                    "rule_name": "cookie2",
                    "client_domain": "incorrect.com",
                    "client_path": "/this/",
                    "server_domain": "absolute.com",
                    "server_path": "/this/",
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] bypass_lists: Specifies a list of URIs to bypass inside a web page when the page is accessed using Portal Access.
        :param pulumi.Input[_builtins.str] ca_file: Specifies a CA against which to verify signed Java applets signatures. (name should be in full path which is combination of partition and CA file name )
        :param pulumi.Input[_builtins.str] cache_type: Specifies the type of Client caching. Valid choices are: `cache-css-js, cache-all, no-cache, cache-img-css-js`. Default value: `cache-img-css-js`
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteCookieRuleArgs', 'ProfileRewriteCookieRuleArgsDict']]]] cookie_rules: Specifies the cookie rewrite rules. Block type. Each request is block type with following arguments.
        :param pulumi.Input[_builtins.str] crl_file: Specifies a CRL against which to verify signed Java applets signature certificates. The default option is `none`.
        :param pulumi.Input[_builtins.str] defaults_from: Specifies the profile from which this profile inherits settings. The default is the system-supplied `rewrite` profile.
        :param pulumi.Input[_builtins.str] name: Name of the rewrite profile. ( profile name should be in full path which is combination of partition and profile name )
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteRequestArgs', 'ProfileRewriteRequestArgsDict']]]] requests: Block type. Each request is block type with following arguments.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteResponseArgs', 'ProfileRewriteResponseArgsDict']]]] responses: Block type. Each request is block type with following arguments.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] rewrite_lists: Specifies a list of URIs to rewrite inside a web page when the page is accessed using Portal Access.
        :param pulumi.Input[_builtins.str] rewrite_mode: Specifies the type of Client caching. Valid choices are: `portal, uri-translation`
        :param pulumi.Input[_builtins.str] signing_cert: Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and certificate name )
        :param pulumi.Input[_builtins.str] signing_key: Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and key name )
        :param pulumi.Input[_builtins.str] signing_key_password: Specifies a pass phrase to use for encrypting the private signing key. Since it's a sensitive entity idempotency will fail in the update call.
        :param pulumi.Input[_builtins.str] split_tunneling: Specifies the type of Client caching. Valid choices are: `true, false`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProfileRewriteArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `bigip_ltm_rewrite_profile` Configures ltm policies to manage traffic assigned to a virtual server

        For resources should be named with their `full path`. The full path is the combination of the `partition + name` of the resource. For example `/Common/test-profile`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        test_profile = f5bigip.ltm.ProfileRewrite("test-profile",
            name="/Common/tf_profile",
            defaults_from="/Common/rewrite",
            bypass_lists=["http://notouch.com"],
            rewrite_lists=["http://some.com"],
            rewrite_mode="portal",
            cache_type="cache-img-css-js",
            ca_file="/Common/ca-bundle.crt",
            crl_file="none",
            signing_cert="/Common/default.crt",
            signing_key="/Common/default.key",
            split_tunneling="true")
        test_profile2 = f5bigip.ltm.ProfileRewrite("test-profile2",
            name="/Common/tf_profile_translate",
            defaults_from="/Common/rewrite",
            rewrite_mode="uri-translation",
            requests=[{
                "insert_xfwd_for": "enabled",
                "insert_xfwd_host": "disabled",
                "insert_xfwd_protocol": "enabled",
                "rewrite_headers": "disabled",
            }],
            responses=[{
                "rewrite_content": "enabled",
                "rewrite_headers": "disabled",
            }],
            cookie_rules=[
                {
                    "rule_name": "cookie1",
                    "client_domain": "wrong.com",
                    "client_path": "/this/",
                    "server_domain": "wrong.com",
                    "server_path": "/this/",
                },
                {
                    "rule_name": "cookie2",
                    "client_domain": "incorrect.com",
                    "client_path": "/this/",
                    "server_domain": "absolute.com",
                    "server_path": "/this/",
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param ProfileRewriteArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProfileRewriteArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bypass_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ca_file: Optional[pulumi.Input[_builtins.str]] = None,
                 cache_type: Optional[pulumi.Input[_builtins.str]] = None,
                 cookie_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteCookieRuleArgs', 'ProfileRewriteCookieRuleArgsDict']]]]] = None,
                 crl_file: Optional[pulumi.Input[_builtins.str]] = None,
                 defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 requests: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteRequestArgs', 'ProfileRewriteRequestArgsDict']]]]] = None,
                 responses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteResponseArgs', 'ProfileRewriteResponseArgsDict']]]]] = None,
                 rewrite_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 rewrite_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 signing_cert: Optional[pulumi.Input[_builtins.str]] = None,
                 signing_key: Optional[pulumi.Input[_builtins.str]] = None,
                 signing_key_password: Optional[pulumi.Input[_builtins.str]] = None,
                 split_tunneling: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProfileRewriteArgs.__new__(ProfileRewriteArgs)

            __props__.__dict__["bypass_lists"] = bypass_lists
            __props__.__dict__["ca_file"] = ca_file
            __props__.__dict__["cache_type"] = cache_type
            __props__.__dict__["cookie_rules"] = cookie_rules
            __props__.__dict__["crl_file"] = crl_file
            __props__.__dict__["defaults_from"] = defaults_from
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["requests"] = requests
            __props__.__dict__["responses"] = responses
            __props__.__dict__["rewrite_lists"] = rewrite_lists
            if rewrite_mode is None and not opts.urn:
                raise TypeError("Missing required property 'rewrite_mode'")
            __props__.__dict__["rewrite_mode"] = rewrite_mode
            __props__.__dict__["signing_cert"] = signing_cert
            __props__.__dict__["signing_key"] = signing_key
            __props__.__dict__["signing_key_password"] = None if signing_key_password is None else pulumi.Output.secret(signing_key_password)
            __props__.__dict__["split_tunneling"] = split_tunneling
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["signingKeyPassword"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ProfileRewrite, __self__).__init__(
            'f5bigip:ltm/profileRewrite:ProfileRewrite',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bypass_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            ca_file: Optional[pulumi.Input[_builtins.str]] = None,
            cache_type: Optional[pulumi.Input[_builtins.str]] = None,
            cookie_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteCookieRuleArgs', 'ProfileRewriteCookieRuleArgsDict']]]]] = None,
            crl_file: Optional[pulumi.Input[_builtins.str]] = None,
            defaults_from: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            requests: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteRequestArgs', 'ProfileRewriteRequestArgsDict']]]]] = None,
            responses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteResponseArgs', 'ProfileRewriteResponseArgsDict']]]]] = None,
            rewrite_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            rewrite_mode: Optional[pulumi.Input[_builtins.str]] = None,
            signing_cert: Optional[pulumi.Input[_builtins.str]] = None,
            signing_key: Optional[pulumi.Input[_builtins.str]] = None,
            signing_key_password: Optional[pulumi.Input[_builtins.str]] = None,
            split_tunneling: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProfileRewrite':
        """
        Get an existing ProfileRewrite resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] bypass_lists: Specifies a list of URIs to bypass inside a web page when the page is accessed using Portal Access.
        :param pulumi.Input[_builtins.str] ca_file: Specifies a CA against which to verify signed Java applets signatures. (name should be in full path which is combination of partition and CA file name )
        :param pulumi.Input[_builtins.str] cache_type: Specifies the type of Client caching. Valid choices are: `cache-css-js, cache-all, no-cache, cache-img-css-js`. Default value: `cache-img-css-js`
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteCookieRuleArgs', 'ProfileRewriteCookieRuleArgsDict']]]] cookie_rules: Specifies the cookie rewrite rules. Block type. Each request is block type with following arguments.
        :param pulumi.Input[_builtins.str] crl_file: Specifies a CRL against which to verify signed Java applets signature certificates. The default option is `none`.
        :param pulumi.Input[_builtins.str] defaults_from: Specifies the profile from which this profile inherits settings. The default is the system-supplied `rewrite` profile.
        :param pulumi.Input[_builtins.str] name: Name of the rewrite profile. ( profile name should be in full path which is combination of partition and profile name )
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteRequestArgs', 'ProfileRewriteRequestArgsDict']]]] requests: Block type. Each request is block type with following arguments.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProfileRewriteResponseArgs', 'ProfileRewriteResponseArgsDict']]]] responses: Block type. Each request is block type with following arguments.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] rewrite_lists: Specifies a list of URIs to rewrite inside a web page when the page is accessed using Portal Access.
        :param pulumi.Input[_builtins.str] rewrite_mode: Specifies the type of Client caching. Valid choices are: `portal, uri-translation`
        :param pulumi.Input[_builtins.str] signing_cert: Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and certificate name )
        :param pulumi.Input[_builtins.str] signing_key: Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and key name )
        :param pulumi.Input[_builtins.str] signing_key_password: Specifies a pass phrase to use for encrypting the private signing key. Since it's a sensitive entity idempotency will fail in the update call.
        :param pulumi.Input[_builtins.str] split_tunneling: Specifies the type of Client caching. Valid choices are: `true, false`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProfileRewriteState.__new__(_ProfileRewriteState)

        __props__.__dict__["bypass_lists"] = bypass_lists
        __props__.__dict__["ca_file"] = ca_file
        __props__.__dict__["cache_type"] = cache_type
        __props__.__dict__["cookie_rules"] = cookie_rules
        __props__.__dict__["crl_file"] = crl_file
        __props__.__dict__["defaults_from"] = defaults_from
        __props__.__dict__["name"] = name
        __props__.__dict__["requests"] = requests
        __props__.__dict__["responses"] = responses
        __props__.__dict__["rewrite_lists"] = rewrite_lists
        __props__.__dict__["rewrite_mode"] = rewrite_mode
        __props__.__dict__["signing_cert"] = signing_cert
        __props__.__dict__["signing_key"] = signing_key
        __props__.__dict__["signing_key_password"] = signing_key_password
        __props__.__dict__["split_tunneling"] = split_tunneling
        return ProfileRewrite(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="bypassLists")
    def bypass_lists(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Specifies a list of URIs to bypass inside a web page when the page is accessed using Portal Access.
        """
        return pulumi.get(self, "bypass_lists")

    @_builtins.property
    @pulumi.getter(name="caFile")
    def ca_file(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies a CA against which to verify signed Java applets signatures. (name should be in full path which is combination of partition and CA file name )
        """
        return pulumi.get(self, "ca_file")

    @_builtins.property
    @pulumi.getter(name="cacheType")
    def cache_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the type of Client caching. Valid choices are: `cache-css-js, cache-all, no-cache, cache-img-css-js`. Default value: `cache-img-css-js`
        """
        return pulumi.get(self, "cache_type")

    @_builtins.property
    @pulumi.getter(name="cookieRules")
    def cookie_rules(self) -> pulumi.Output[Optional[Sequence['outputs.ProfileRewriteCookieRule']]]:
        """
        Specifies the cookie rewrite rules. Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "cookie_rules")

    @_builtins.property
    @pulumi.getter(name="crlFile")
    def crl_file(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies a CRL against which to verify signed Java applets signature certificates. The default option is `none`.
        """
        return pulumi.get(self, "crl_file")

    @_builtins.property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the profile from which this profile inherits settings. The default is the system-supplied `rewrite` profile.
        """
        return pulumi.get(self, "defaults_from")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the rewrite profile. ( profile name should be in full path which is combination of partition and profile name )
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def requests(self) -> pulumi.Output[Sequence['outputs.ProfileRewriteRequest']]:
        """
        Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "requests")

    @_builtins.property
    @pulumi.getter
    def responses(self) -> pulumi.Output[Sequence['outputs.ProfileRewriteResponse']]:
        """
        Block type. Each request is block type with following arguments.
        """
        return pulumi.get(self, "responses")

    @_builtins.property
    @pulumi.getter(name="rewriteLists")
    def rewrite_lists(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Specifies a list of URIs to rewrite inside a web page when the page is accessed using Portal Access.
        """
        return pulumi.get(self, "rewrite_lists")

    @_builtins.property
    @pulumi.getter(name="rewriteMode")
    def rewrite_mode(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the type of Client caching. Valid choices are: `portal, uri-translation`
        """
        return pulumi.get(self, "rewrite_mode")

    @_builtins.property
    @pulumi.getter(name="signingCert")
    def signing_cert(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and certificate name )
        """
        return pulumi.get(self, "signing_cert")

    @_builtins.property
    @pulumi.getter(name="signingKey")
    def signing_key(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies a certificate to use for re-signing of signed Java applets after patching. (name should be in full path which is combination of partition and key name )
        """
        return pulumi.get(self, "signing_key")

    @_builtins.property
    @pulumi.getter(name="signingKeyPassword")
    def signing_key_password(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies a pass phrase to use for encrypting the private signing key. Since it's a sensitive entity idempotency will fail in the update call.
        """
        return pulumi.get(self, "signing_key_password")

    @_builtins.property
    @pulumi.getter(name="splitTunneling")
    def split_tunneling(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the type of Client caching. Valid choices are: `true, false`
        """
        return pulumi.get(self, "split_tunneling")

